socket property

  1. @override
Future<Socket> socket
final

A Future that completes with value that S.connect() would return unless cancel is called on this ConnectionTask.

If cancel is called, the future completes with a SocketException error whose message indicates that the connection attempt was cancelled.

Implementation

@override
final Future<Socket> socket;